function Dist = CalculateIntraClassDist(Feature, Class, DistType)
% Calculate the intra-class distance (as used in K-means) of the current clustering
%
% Input
%   - Feature       : each row is a feature vector
%   - Class         : each row is a cluster label
%   - DistType      : 'Euclidean' (default) or 'Mahalanobis' distance
% Output
%   - Dist          : the intra-class distance
%
% Author: Zhiyao Duan
% Created: 6/20/2012
% Last modified: 6/20/2012

if nargin<3
    DistType = 'Euclidean';
end

Dist = 0;
% calculate centers
uClass = unique(Class)';
for track = uClass
    idx = Class==track;
    trackCenter = mean(Feature(idx, :), 1);
    if strcmp(DistType, 'Euclidean')
        Dist = Dist + sum(sum( (Feature(idx,:) - repmat(trackCenter,sum(idx),1)).^2 ));
    elseif strcmp(DistType, 'Mahalanobis')
        trackCovInv = 0.9*inv(cov(Feature(idx,:))) + 0.1*eye(length(trackCenter));
        Dist = Dist + trace((Feature(idx,:)-repmat(trackCenter,sum(idx),1)) * trackCovInv * (Feature(idx,:)-repmat(trackCenter,sum(idx),1))');
    else
        error('Unknown distance type!');
    end
end