function NewSwapSet = FindSwapSet(InitSwapSet, currCluster, targCluster, Cluster, MustLink, CannotLink)
% Find the swap set containing the original SwapSet. A swap set is a set of
% instances of two clusters. These instances are connected by must-links
% and cannot-links between the two clusters.
% 
% Input:
%   - InitSwapSet   : the initial swap set. It shouldn't have instances
%                     from more than two clusters.
%   - currCluster   : the currCluster
%   - targCluster   : the target cluster where new instances will be added from
%   - Cluster       : cluster labels
%   - MustLink      : must-link relations
%   - CannotLink    : cannot-link relations
% Output:
%   - NewSwapSet    : the final calculated swap set
%
% Author: Zhiyao Duan
% Created: 6/20/2012
% Last modified: 6/20/2012

% find points from the target cluster through cannot-links
targSet = [CannotLink{InitSwapSet}];
idx = Cluster(targSet) == targCluster;
targSet = targSet(idx);

% enlarge targSet through must-links
targSet = FindInstThroughMustLinks(targSet, MustLink);

% include targSet to SwapSet
NewSwapSet = unique([InitSwapSet, targSet]);

% if something new was included, then recursively find the new swap set
% this time we'll add instances from the currCluster. Notice the position
% exchange between currCluster and targCluster.
if length(InitSwapSet) ~= length(NewSwapSet)
    NewSwapSet = FindSwapSet(NewSwapSet, targCluster, currCluster, Cluster, MustLink, CannotLink);
end