function ceps = unidisceps(fk, ak, p)
% ceps = unidisceps(fk, ak, p, lambda)
% Calculate Uniform Discrete Cepstrum (UDC) from spectral peaks. This is a new
% (different) version than Rodet's algorithm. We removed the inverse matrix
% transformation. This algorithm is a strict analogy of cepstrum
% calculation.
%
% Input:
%   - fk    : normalized frequencies of peaks (range from 0 to 1)
%   - ak    : amplitudes of peaks in dB
%   - p     : cepstrum order (there will be p+1 ceps coefficients)
% Output:
%   - ceps  : the discrete cepstrum coefficients
%
% Author: Zhiyao Duan
% Created: 8/9/2012
% Last modified: 9/24/2012

if nargin < 3
    p = 30;
end

% convert row vectors to column vectors
if size(fk, 1) == 1
    fk = fk';
end
if size(ak, 1) == 1
    ak = ak';
end

% add control points
% if min(fk) > 0.005
%     fk = [0.002; fk];
%     ak = [max(ak)/2; ak];
% end
% if max(fk) < 1/3
%     fkFill = (max(fk):0.01:1/3)';
%     fk = [fk; fkFill];
%     ak = [ak; min(ak)/2*ones(size(fkFill))];
% end

% calculate cepstrum coefficients
L = length(fk);
M = zeros(L, p+1);

for m = 1:L
    M(m, 1) = 1;
    for n = 1:p
        M(m, n+1) = 2*cos(2*pi*n*fk(m));
    end
end
ceps = M'*ak;